/*
 * Cueplot: a GUI front end to gnuplot
 * Copyright (C) 2007 Muneyuki Noguchi
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software Foundation, 
 * Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 */
#ifndef LABEL_INCLUDED
#define LABEL_INCLUDED

#include "Option.h"

#include <QString>

class Label : public Option
{
	public:
		Label();

		void setLabel(int axis, const QString &label);
		const QString &label(int axis) const;

		void setXOffset(int axis, double xoff);
		double xOffset(int axis) const;

		void setYOffset(int axis, double yoff);
		double yOffset(int axis) const;

		void setFontName(int axis, const QString &name);
		const QString &fontName(int axis) const;

		void setFontSize(int axis, double size);
		double fontSize(int axis) const;

		void setLineType(int axis, int lt);
		int lineType(int axis) const;

		QString command() const;

	private:
		// 1st -> title, 2nd -> xlabel, 3rd -> ylabel,...
		static const int AXIS_NUM = 7;
		static const double DEFAULT_FONT_SIZE;
		static const int DEFAULT_LINE_TYPE = 0;
		QString labelArray[AXIS_NUM];
		double xOffsetArray[AXIS_NUM];
		double yOffsetArray[AXIS_NUM];
		QString fontNameArray[AXIS_NUM];
		double fontSizeArray[AXIS_NUM];
		int lineTypeArray[AXIS_NUM];
};
#endif // LABEL_INCLUDED
